@@ -83,16 +83,12 @@ func eventMapping(r mb.ReporterV2, info elasticsearch.Info, content []byte) erro
 
 	err := json.Unmarshal(content, &all)
 	if err != nil {
-		event.Error = errors.Wrap(err, "failure parsing Elasticsearch Stats API response")
-		r.Event(event)
-		return event.Error
+		return errors.Wrap(err, "failure parsing Elasticsearch Stats API response")
 	}
 
 	fields, err := schema.Apply(all.Data, s.FailOnRequired)
 	if err != nil {
-		event.Error = errors.Wrap(err, "failure applying stats schema")
-		r.Event(event)
-		return event.Error
+		return errors.Wrap(err, "failure applying stats schema")
 	}
 
 	event.MetricSetFields = fields
